from simple_avk.AVK import SimpleAVK
from simple_avk.AVK import VKError
